InitialState

Trait InitialState 

pub trait InitialState { }
Marker for creating a new initial state. This trait enforces that only the initial state can be created manually while all others must be created through a proper state transition.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors